Package: MSstatsShiny
Type: Package
Title: MSstats GUI for Statistical Anaylsis of Proteomics Experiments
Version: 1.15.5
Description: MSstatsShiny is an R-Shiny graphical user interface (GUI) 
  integrated with the R packages MSstats, MSstatsTMT, and MSstatsPTM. It 
  provides a point and click end-to-end analysis pipeline applicable to a wide 
  variety of experimental designs. These include data-dependedent acquisitions (DDA)
  which are label-free or tandem mass tag (TMT)-based, as well as DIA, SRM, and 
  PRM acquisitions and those targeting post-translational modifications (PTMs). 
  The application automatically saves users selections and builds an R script 
  that recreates their analysis, supporting reproducible data analysis.
Authors@R: c(
    person("Devon", "Kohler", email = "kohler.d@northeastern.edu", role = c("aut")),
    person("Anthony", "Wu", email = "wu.anthon@northeastern.edu", role = c("aut", "cre")),
    person("Deril", "Raju", email = "raju.d@northeastern.edu", role = c("aut")),
    person("Maanasa", "Kaza", email = "maanasakaza@gmail.com", role = c("aut")),
    person("Cristina", "Pasi", email = "cristinapasi@gmail.com", role = c("aut")),
    person("Ting", "Huang", email = "thuang0703@gmail.com", role = c("aut")),
    person("Mateusz", "Staniak", email = "mateusz.staniak@math.uni.wroc.pl", role = c("aut")),
    person("Dhaval", "Mohandas", email = "dhavalmohandas@gmail.com", role = c("aut")),
    person("Eduard", "Sabido", email = "eduard.sabido@crg.cat", role = c("aut")),
    person("Meena", "Choi", email = "choi.meena@gene.com", role = c("aut")),
    person("Olga", "Vitek", email = "o.vitek@northeastern.edu", role = "aut"))
License: Artistic-2.0
Depends: R (>= 4.2)
Imports: shiny (>= 1.5.0), shinyBS, shinyjs, shinybusy, dplyr, ggplot2,
        plotly, data.table, Hmisc, shinyFiles, MSstats,MSstatsBig,
        MSstatsTMT, MSstatsPTM, MSstatsConvert, gplots, marray, DT,
        readxl, ggrepel, uuid, utils, stats, htmltools, methods, tidyr,
        grDevices, graphics, mockery, MSstatsBioNet, shinydashboard,
        arrow, tools, MSstatsResponse, stringr, httr
Suggests: rmarkdown, tinytest, sessioninfo, knitr, testthat (>= 3.0.0),
        shinytest2,
VignetteBuilder: knitr
biocViews: ImmunoOncology, MassSpectrometry, Proteomics, Software,
        ShinyApps, DifferentialExpression, OneChannel, TwoChannel,
        Normalization, QualityControl, GUI
BugReports: https://github.com/Vitek-Lab/MSstatsShiny/issues
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
git_url: https://git.bioconductor.org/packages/MSstatsShiny
git_branch: devel
git_last_commit: 8bee970
git_last_commit_date: 2026-08-01
Repository: Bioconductor 3.24
Date/Publication: 2026-08-02
NeedsCompilation: no
Packaged: 2026-08-02 23:12:03 UTC; biocbuild
Author: Devon Kohler [aut],
  Anthony Wu [aut, cre],
  Deril Raju [aut],
  Maanasa Kaza [aut],
  Cristina Pasi [aut],
  Ting Huang [aut],
  Mateusz Staniak [aut],
  Dhaval Mohandas [aut],
  Eduard Sabido [aut],
  Meena Choi [aut],
  Olga Vitek [aut]
Maintainer: Anthony Wu <wu.anthon@northeastern.edu>
