---
title: "MSstatsShiny Launch Instructions"
author: "Devon Kohler (<kohler.d@northeastern.edu>)"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{MSstatsPTM LabelFree Workflow}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width=8, 
  fig.height=8
)
```

This Vignette goes over how to launch the `MSstatsShiny` R shiny application. 

## Installation

To install this package, start R (version "4.0") and enter:

``` {r, eval = FALSE}
if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")

BiocManager::install("MSstatsShiny")
```

```{r, message=FALSE, warning=FALSE}
library(MSstatsShiny)
```

# 1. Introduction

`MSstatsShiny` is an R-shiny based GUI package integrated with the 
`MSstats` family of packages. The package allows users to analyze a variety of 
proteomic experiments, including those processed using different labeling 
methods, spectral processing tools, and targeting different biological questions
of interest. It is designed to enhance the usability of the `MSstats` packages, 
bringing them to a wider user base, including those who do not have have 
experience coding in R. The GUI is designed to be general, reproducible, and 
scalable, as well as easily usable by all users. Finally, it enhances both 
reproducibility and collaboration through documenting analyses via code, which 
recreates the user's analysis exactly.

# 2. Launch Function

After installation, running the application is as simple as executing a single 
command.

```{r, eval = FALSE, message=FALSE, warning=FALSE}
launch_MSstatsShiny()
```

Once this command is executed, the application will automatically start up in a 
different window. You can still view any warnings or errors in the R console 
where you ran the function. This can be helpful when debugging.

# 3. Cloud Version

`MSstatsShiny` is also available on the cloud at \url{www.msstatsshiny.com}. Due
to RAM constraints, the cloud version of the application is limited to files 
under 250 MB. Any larger files should be processed in a local instance of the 
application.

# 4. Session Info

```{r}
sessioninfo::session_info()
```


