% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dataDoc.R
\docType{data}
\name{raw.pd}
\alias{raw.pd}
\title{Example output file PD}
\format{
data.frame
}
\description{
data.frame containing output of PD. Used in examples.
}
\examples{
data(raw.pd)
head(raw.pd)

}
